@@ -4,8 +4,10 @@
 
 mod extractor;
 mod query;
+mod response;
 mod subscription;
 
 pub use extractor::{GraphQLBatchRequest, GraphQLRequest};
 pub use query::GraphQL;
+pub use response::{GraphQLBatchResponse, GraphQLResponse};
 pub use subscription::GraphQLSubscription;
